emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/trunk r101719: xml.c: Rework the functions


From: Lars Magne Ingebrigtsen
Subject: [Emacs-diffs] /srv/bzr/emacs/trunk r101719: xml.c: Rework the functions to take regions instead of strings,
Date: Sat, 02 Oct 2010 02:36:47 +0200
User-agent: Bazaar (2.0.3)

------------------------------------------------------------
revno: 101719
committer: Lars Magne Ingebrigtsen <address@hidden>
branch nick: trunk
timestamp: Sat 2010-10-02 02:36:47 +0200
message:
  xml.c: Rework the functions to take regions instead of strings,
  and rename the functions to reflect clearly that they come from the
  libxml package.
modified:
  src/ChangeLog
  src/xml.c
=== modified file 'src/ChangeLog'
--- a/src/ChangeLog     2010-10-01 20:18:24 +0000
+++ b/src/ChangeLog     2010-10-02 00:36:47 +0000
@@ -1,3 +1,9 @@
+2010-10-02  Lars Magne Ingebrigtsen  <address@hidden>
+
+       * xml.c (Flibxml_parse_xml_region, Flibxml_parse_html_region)
+       (parse_region): Reworked to take regions instead of strings, and
+       renamed to reflect that these are the libxml functions.
+
 2010-10-01  Eli Zaretskii  <address@hidden>
 
        * term.c (init_tty) [DOS_NT]: Don't call Wcm_clear after setting

=== modified file 'src/xml.c'
--- a/src/xml.c 2010-09-30 23:26:40 +0000
+++ b/src/xml.c 2010-10-02 00:36:47 +0000
@@ -74,17 +74,24 @@
 }
 
 static Lisp_Object
-parse_string (Lisp_Object string, Lisp_Object base_url, int htmlp)
+parse_region (Lisp_Object start, Lisp_Object end, Lisp_Object base_url, int 
htmlp)
 {
   xmlDoc *doc;
   xmlNode *node;
   Lisp_Object result = Qnil;
-  int ibeg, iend;
   const char *burl = "";
+  EMACS_INT bytes;
+  EMACS_INT istart, iend;
 
   LIBXML_TEST_VERSION;
 
-  CHECK_STRING (string);
+  validate_region (&start, &end);
+  
+  istart = XINT (start);
+  iend = XINT (end);
+
+  if (istart < GPT && GPT < iend)
+    move_gap (iend);
 
   if (! NILP (base_url))
     {
@@ -92,13 +99,18 @@
       burl = SDATA (base_url);
     }
 
-  doc = htmlp
-    ? htmlReadMemory (SDATA (string), SBYTES (string), burl, "utf-8",
-                     HTML_PARSE_RECOVER|HTML_PARSE_NONET|
-                     HTML_PARSE_NOWARNING|HTML_PARSE_NOERROR)
-    : xmlReadMemory (SDATA (string), SBYTES (string), burl, "utf-8",
-                    XML_PARSE_NONET|XML_PARSE_NOWARNING|
-                    XML_PARSE_NOERROR);
+  bytes = CHAR_TO_BYTE (iend) - CHAR_TO_BYTE (istart);
+  
+  if (htmlp)
+    doc = htmlReadMemory (BYTE_POS_ADDR (CHAR_TO_BYTE (istart)),
+                         bytes, burl, "utf-8",
+                         HTML_PARSE_RECOVER|HTML_PARSE_NONET|
+                         HTML_PARSE_NOWARNING|HTML_PARSE_NOERROR);
+  else
+    doc = xmlReadMemory (BYTE_POS_ADDR (CHAR_TO_BYTE (istart)),
+                        bytes, burl, "utf-8",
+                        XML_PARSE_NONET|XML_PARSE_NOWARNING|
+                        XML_PARSE_NOERROR);
 
   if (doc != NULL)
     {
@@ -112,24 +124,24 @@
   return result;
 }
 
-DEFUN ("xml-parse-html-string-internal", Fxml_parse_html_string_internal,
-       Sxml_parse_html_string_internal,
-       1, 2, 0,
-       doc: /* Parse STRING as an HTML document and return the parse tree.
+DEFUN ("libxml-parse-html-region", Flibxml_parse_html_region,
+       Slibxml_parse_html_region,
+       2, 3, 0,
+       doc: /* Parse the region as an HTML document and return the parse tree.
 If BASE-URL is non-nil, it is used to expand relative URLs.  */)
-  (Lisp_Object string, Lisp_Object base_url)
+  (Lisp_Object start, Lisp_Object end, Lisp_Object base_url)
 {
-  return parse_string (string, base_url, 1);
+  return parse_region (start, end, base_url, 1);
 }
 
-DEFUN ("xml-parse-string-internal", Fxml_parse_string_internal,
-       Sxml_parse_string_internal,
-       1, 2, 0,
-       doc: /* Parse STRING as an XML document and return the parse tree.
+DEFUN ("libxml-parse-xml-region", Flibxml_parse_xml_region,
+       Slibxml_parse_xml_region,
+       2, 3, 0,
+       doc: /* Parse the region as an XML document and return the parse tree.
 If BASE-URL is non-nil, it is used to expand relative URLs.  */)
-  (Lisp_Object string, Lisp_Object base_url)
+  (Lisp_Object start, Lisp_Object end, Lisp_Object base_url)
 {
-  return parse_string (string, base_url, 0);
+  return parse_region (start, end, base_url, 0);
 }
 
 
@@ -139,8 +151,8 @@
 void
 syms_of_xml (void)
 {
-  defsubr (&Sxml_parse_html_string_internal);
-  defsubr (&Sxml_parse_string_internal);
+  defsubr (&Slibxml_parse_html_region);
+  defsubr (&Slibxml_parse_xml_region);
 }
 
 #endif /* HAVE_LIBXML2 */


reply via email to

[Prev in Thread] Current Thread [Next in Thread]